@@ -10,7 +10,7 @@ import wagtail_localize_rws_languagecloud.sync as sync
 
 from wagtail_localize.models import Translation
 
-from ..models import LanguageCloudFile, LanguageCloudProject
+from ..models import LanguageCloudFile, LanguageCloudProject, LanguageCloudStatus
 from ..rws_client import ApiClient
 from .helpers import create_test_page, create_test_po, create_test_project_settings
 
@@ -67,14 +67,16 @@ class TestImport(TestCase):
         client = ApiClient()
         client.is_authorized = True
         client.get_project = Mock(
-            side_effect=[{"status": "completed"}, {"status": "completed"}], spec=True
+            side_effect=[{"status": "completed"}, {"status": "inProgress"}], spec=True
         )
         client.download_target_file = Mock(
             side_effect=[str(self.po_files[0]), str(self.po_files[1])], spec=True
         )
+        client.complete_project = Mock(spec=True)
         sync._import(client, self.logger)
         self.assertEqual(client.get_project.call_count, 2)
         self.assertEqual(client.download_target_file.call_count, 2)
+        self.assertEqual(client.complete_project.call_count, 1)
         for proj in self.lc_projects:
             proj.refresh_from_db()
             self.assertEqual(proj.internal_status, LanguageCloudProject.STATUS_IMPORTED)
@@ -90,9 +92,11 @@ class TestImport(TestCase):
         client.download_target_file = Mock(
             side_effect=ValueError("this should never be called"), spec=True
         )
+        client.complete_project = Mock(spec=True)
         sync._import(client, self.logger)
         self.assertEqual(client.get_project.call_count, 2)
         self.assertEqual(client.download_target_file.call_count, 0)
+        self.assertEqual(client.complete_project.call_count, 0)
         for proj in self.lc_projects:
             proj.refresh_from_db()
             self.assertEqual(proj.internal_status, LanguageCloudProject.STATUS_NEW)
@@ -107,14 +111,16 @@ class TestImport(TestCase):
         client = ApiClient()
         client.is_authorized = True
         client.get_project = Mock(
-            side_effect=[RequestException("oh no"), {"status": "completed"}], spec=True
+            side_effect=[RequestException("oh no"), {"status": "inProgress"}], spec=True
         )
         client.download_target_file = Mock(
             side_effect=[str(self.po_files[0]), str(self.po_files[1])], spec=True
         )
+        client.complete_project = Mock(spec=True)
         sync._import(client, self.logger)
         self.assertEqual(client.get_project.call_count, 2)
         self.assertEqual(client.download_target_file.call_count, 1)
+        self.assertEqual(client.complete_project.call_count, 1)
         for proj in self.lc_projects:
             proj.refresh_from_db()
         for file_ in self.lc_files:
@@ -141,34 +147,39 @@ class TestImport(TestCase):
     def test_import_no_records_to_process(self):
         self.lc_projects[0].internal_status = LanguageCloudProject.STATUS_IMPORTED
         self.lc_projects[0].save()
-        self.lc_projects[1].lc_project_status = "archived"
+        self.lc_projects[1].lc_project_status = LanguageCloudStatus.ARCHIVED
         self.lc_projects[1].save()
 
         client = ApiClient()
         client.is_authorized = True
         client.get_project = Mock(
-            side_effect=[{"status": "complete"}, {"status": "complete"}], spec=True
+            side_effect=[{"status": "doesn't matter"}, {"status": "doesn't matter"}],
+            spec=True,
         )
         client.download_target_file = Mock(
             side_effect=[self.po_files[0], self.po_files[1]], spec=True
         )
+        client.complete_project = Mock(spec=True)
         sync._import(client, self.logger)
         self.assertEqual(client.get_project.call_count, 0)
         self.assertEqual(client.download_target_file.call_count, 0)
+        self.assertEqual(client.complete_project.call_count, 0)
 
     def test_import_with_an_exception_finished_processing(self):
         client = ApiClient()
         client.is_authorized = True
         client.get_project = Mock(
-            side_effect=[{"status": "completed"}, Exception()], spec=True
+            side_effect=[{"status": "inProgress"}, Exception()], spec=True
         )
         client.download_target_file = Mock(
             side_effect=[str(self.po_files[0]), str(self.po_files[1])], spec=True
         )
+        client.complete_project = Mock(spec=True)
 
         sync._import(client, self.logger)
         self.assertEqual(client.get_project.call_count, 2)
         self.assertEqual(client.download_target_file.call_count, 1)
+        self.assertEqual(client.complete_project.call_count, 1)
 
         self.lc_projects[0].refresh_from_db()
         self.assertEqual(
@@ -251,10 +262,16 @@ class TestExport(TestCase):
             spec=True,
         )
         client.get_project_templates = self.get_project_templates_mock
+        client.start_project = Mock()
+
         sync._export(client, self.logger)
 
         self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 4)
+        self.assertEqual(client.start_project.call_count, 2)
+        # check start_project was called with the project id as a param
+        client.start_project.assert_called_with("proj2")
+
         lc_projects = [
             LanguageCloudProject.objects.all().get(
                 translation_source=s,
@@ -305,14 +322,14 @@ class TestExport(TestCase):
         client.get_project_templates = self.get_project_templates_mock
         sync._export(client, self.logger)
 
-        self.assertEqual(client.create_project.call_count, 4)
+        self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 0)
 
         lc_projects = LanguageCloudProject.objects.all()
         self.assertEqual(len(lc_projects), 2)
         for proj in lc_projects:
             self.assertEqual(proj.lc_project_id, "")
-            self.assertEqual(proj.create_attempts, 2)
+            self.assertEqual(proj.create_attempts, 1)
 
         lc_files = LanguageCloudFile.objects.all()
         self.assertEqual(len(lc_files), 4)
@@ -326,7 +343,6 @@ class TestExport(TestCase):
         client.is_authorized = True
         client.create_project = Mock(
             side_effect=[
-                RequestException("oh no"),
                 RequestException("oh no"),
                 {"id": "proj2"},
             ],
@@ -336,10 +352,13 @@ class TestExport(TestCase):
             side_effect=[{"id": "file3"}, {"id": "file4"}], spec=True
         )
         client.get_project_templates = self.get_project_templates_mock
+        client.start_project = Mock()
 
         sync._export(client, self.logger)
-        self.assertEqual(client.create_project.call_count, 3)
+        self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 2)
+        self.assertEqual(client.start_project.call_count, 1)
+
         lc_projects = [
             LanguageCloudProject.objects.all().get(
                 translation_source=s,
@@ -349,7 +368,7 @@ class TestExport(TestCase):
         ]
 
         self.assertEqual(lc_projects[0].lc_project_id, "")
-        self.assertEqual(lc_projects[0].create_attempts, 2)
+        self.assertEqual(lc_projects[0].create_attempts, 1)
         proj1_files = (
             lc_projects[0].languagecloudfile_set.all().order_by("lc_source_file_id")
         )
@@ -392,10 +411,14 @@ class TestExport(TestCase):
             spec=True,
         )
         client.get_project_templates = self.get_project_templates_mock
+        client.start_project = Mock()
+
         sync._export(client, self.logger)
 
         self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 4)
+        self.assertEqual(client.start_project.call_count, 0)
+
         lc_projects = [
             LanguageCloudProject.objects.all().get(
                 translation_source=s,
@@ -448,9 +471,12 @@ class TestExport(TestCase):
         client.create_source_file = Mock(
             side_effect=[{"id": "def123"}, {"id": "def456"}], spec=True
         )
+        client.start_project = Mock()
+
         sync._export(client, self.logger)
         self.assertEqual(client.create_project.call_count, 0)
         self.assertEqual(client.create_source_file.call_count, 0)
+        self.assertEqual(client.start_project.call_count, 0)
 
     def test_export_with_an_exception_finished_processing(self):
         client = ApiClient()
@@ -463,9 +489,11 @@ class TestExport(TestCase):
             side_effect=[{"id": "file1"}, {"id": "file2"}, {"id": "file3"}],
             spec=True,
         )
+        client.start_project = Mock()
         sync._export(client, self.logger)
-        self.assertEqual(client.create_project.call_count, 3)
+        self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 2)
+        self.assertEqual(client.start_project.call_count, 1)
 
         lc_projects = [
             LanguageCloudProject.objects.all().get(
@@ -508,11 +536,48 @@ class TestExport(TestCase):
             spec=True,
         )
         client.get_project_templates = self.get_project_templates_mock
+        client.start_project = Mock()
+
         sync._export(client, self.logger)
 
         self.assertEqual(LanguageCloudProject.objects.count(), 2)
         self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 4)
+        self.assertEqual(client.start_project.call_count, 2)
+
+    def test_export_will_mark_project_as_in_progress_if_started_remotely(self):
+        client = ApiClient()
+        client.create_project = Mock(
+            side_effect=[{"id": "proj1"}, {"id": "proj2"}], spec=True
+        )
+        client.create_source_file = Mock(
+            side_effect=[
+                {"id": "file1"},
+                {"id": "file2"},
+                {"id": "file3"},
+                {"id": "file4"},
+            ],
+            spec=True,
+        )
+        client.get_project_templates = self.get_project_templates_mock
+        client.start_project = Mock(
+            side_effect=[True, RequestException("oh no")],
+            spec=True,
+        )
+
+        sync._export(client, self.logger)
+        self.assertEqual(client.create_project.call_count, 2)
+        self.assertEqual(client.create_source_file.call_count, 4)
+        self.assertEqual(client.start_project.call_count, 2)
+
+        self.assertListEqual(
+            list(
+                LanguageCloudProject.objects.all()
+                .values_list("lc_project_status", flat=True)
+                .order_by("pk")
+            ),
+            [LanguageCloudStatus.IN_PROGRESS, LanguageCloudStatus.CREATED],
+        )
 
 
 class TestHelpers(TestCase):
@@ -634,78 +699,248 @@ class TestHelpers(TestCase):
         self.assertEqual(lc_source_file.lc_source_file_id, "")
         self.assertEqual(lc_source_file.create_attempts, 1)
 
-    def test_should_not_export_already_imported(self):
-        self.assertFalse(
-            sync._should_export(
-                self.logger,
-                LanguageCloudProject(
-                    translation_source=self.translation.source,
-                    source_last_updated_at=self.translation.source.last_updated_at,
-                    internal_status=LanguageCloudProject.STATUS_IMPORTED,
-                ),
-            )
+
+class TestProjectsToExportLogic(TestCase):
+    def setUp(self):
+        self.locale_en = Locale.objects.get(language_code="en")
+        self.locale_fr = Locale.objects.create(language_code="fr")
+        self.locale_de = Locale.objects.create(language_code="de")
+
+        _, self.source = create_test_page(
+            title="Test page",
+            slug="test-page",
+            test_charfield="Some test translatable content",
+        )
+        self.translation_fr = Translation.objects.create(
+            source=self.source,
+            target_locale=self.locale_fr,
         )
 
-    def test_should_export_project_and_source_file_created(self):
-        lc_project = LanguageCloudProject.objects.create(
-            translation_source=self.translation.source,
-            source_last_updated_at=self.translation.source.last_updated_at,
-            lc_project_id="abc123",
+        self.translation_de = Translation.objects.create(
+            source=self.source,
+            target_locale=self.locale_de,
         )
-        self._create_project_settings(lc_project)
-        LanguageCloudFile.objects.create(
-            translation=self.translation,
-            project=lc_project,
-            lc_source_file_id="def456",
-        )
-        self.assertFalse(sync._should_export(self.logger, lc_project))
 
-    def test_should_export_too_many_project_fails(self):
-        lc_project = LanguageCloudProject.objects.create(
-            translation_source=self.translation.source,
-            source_last_updated_at=self.translation.source.last_updated_at,
-            create_attempts=3,
-        )
-        self._create_project_settings(lc_project)
-        LanguageCloudFile.objects.create(
-            translation=self.translation,
-            project=lc_project,
-            create_attempts=0,
-        )
-        self.assertFalse(sync._should_export(self.logger, lc_project))
+        self.logger = logging.getLogger(__name__)
+        logging.disable()  # supress log output under test
 
-    def test_should_export_too_many_file_fails(self):
-        lc_project = LanguageCloudProject.objects.create(
-            translation_source=self.translation.source,
-            source_last_updated_at=self.translation.source.last_updated_at,
-            create_attempts=0,
+    def _add_settings(self):
+        settings, _ = create_test_project_settings(
+            self.source, [self.translation_fr, self.translation_de]
         )
-        self._create_project_settings(lc_project)
-        LanguageCloudFile.objects.create(
-            translation=self.translation,
-            project=lc_project,
-            create_attempts=3,
-        )
-        self.assertFalse(sync._should_export(self.logger, lc_project))
+        return settings
 
-    def test_should_export_new_project(self):
-        lc_project = LanguageCloudProject(
-            translation_source=self.translation.source,
-            source_last_updated_at=self.translation.source.last_updated_at,
-        )
-        self._create_project_settings(lc_project)
-        self.assertTrue(sync._should_export(self.logger, lc_project))
+    def _add_project_from_settings(self):
+        return sync._create_local_project(self._add_settings())
 
-    def test_should_export_fails_under_threshold(self):
-        lc_project = LanguageCloudProject.objects.create(
-            translation_source=self.translation.source,
-            source_last_updated_at=self.translation.source.last_updated_at,
-            create_attempts=2,
+    def test_project_without_settings_will_not_considered(self):
+        LanguageCloudProject.objects.get_or_create(
+            translation_source=self.source,
+            source_last_updated_at=self.source.last_updated_at,
         )
-        self._create_project_settings(lc_project)
-        LanguageCloudFile.objects.create(
-            translation=self.translation,
-            project=lc_project,
-            create_attempts=2,
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_project_with_settings_but_no_files_will_not_be_considered(self):
+        self._add_settings()
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_project_with_settings_and_files_will_be_considered(self):
+        self._add_project_from_settings()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 1)
+
+    def test_project_already_imported_will_not_be_considered(self):
+        project = self._add_project_from_settings()
+        project.internal_status = LanguageCloudProject.STATUS_IMPORTED
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_project_in_progress_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.lc_project_status = LanguageCloudStatus.IN_PROGRESS
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_completed_project_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.lc_project_status = LanguageCloudStatus.COMPLETED
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_archived_project_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.lc_project_status = LanguageCloudStatus.ARCHIVED
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_project_and_all_remote_files_created_will_not_be_considered(self):
+        project = self._add_project_from_settings()
+        project.lc_project_id = "123"
+        project.save()
+
+        for lc_file in project.languagecloudfile_set.all():
+            lc_file.lc_source_file_id = f"foo_{lc_file.id}"
+            lc_file.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_project_created_remotely_but_not_the_files_will_be_considered(self):
+        project = self._add_project_from_settings()
+        project.lc_project_id = "123"
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 1)
+
+    def test_project_with_some_remote_files_created_will_be_considered(self):
+        project = self._add_project_from_settings()
+        lc_file = project.languagecloudfile_set.first()
+        lc_file.lc_source_file_id = "123"
+        lc_file.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 1)
+
+    def test_failed_project_will_not_be_considered(self):
+        project = self._add_project_from_settings()
+        project.create_attempts = 3
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_project_with_all_remote_files_failed_will_not_be_considered(self):
+        project = self._add_project_from_settings()
+        project.save()
+
+        for lc_file in project.languagecloudfile_set.all():
+            lc_file.create_attempts = 3
+            lc_file.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+    def test_project_with_some_remote_files_failed_will_not_be_considered(self):
+        project = self._add_project_from_settings()
+        project.save()
+
+        lc_file = project.languagecloudfile_set.first()
+        lc_file.create_attempts = 3
+        lc_file.save()
+
+        self.assertEqual(sync._get_projects_to_export().count(), 0)
+
+
+class TestProjectsToStartLogic(TestCase):
+    def setUp(self):
+        self.locale_en = Locale.objects.get(language_code="en")
+        self.locale_fr = Locale.objects.create(language_code="fr")
+        self.locale_de = Locale.objects.create(language_code="de")
+
+        _, self.source = create_test_page(
+            title="Test page",
+            slug="test-page",
+            test_charfield="Some test translatable content",
         )
-        self.assertTrue(sync._should_export(self.logger, lc_project))
+        self.translation_fr = Translation.objects.create(
+            source=self.source,
+            target_locale=self.locale_fr,
+        )
+
+        self.translation_de = Translation.objects.create(
+            source=self.source,
+            target_locale=self.locale_de,
+        )
+
+        self.logger = logging.getLogger(__name__)
+        logging.disable()  # supress log output under test
+
+    def _add_settings(self):
+        settings, _ = create_test_project_settings(
+            self.source, [self.translation_fr, self.translation_de]
+        )
+        return settings
+
+    def _add_project_from_settings(self):
+        return sync._create_local_project(self._add_settings())
+
+    def test_project_without_settings_is_excluded(self):
+        LanguageCloudProject.objects.get_or_create(
+            translation_source=self.source,
+            source_last_updated_at=self.source.last_updated_at,
+        )
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_project_with_settings_but_no_files_is_excluded(self):
+        self._add_settings()
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_project_with_settings_and_files_but_none_created_remotely_is_excluded(
+        self,
+    ):
+        self._add_project_from_settings()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_project_already_imported_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.internal_status = LanguageCloudProject.STATUS_IMPORTED
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_project_in_progress_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.lc_project_status = LanguageCloudStatus.IN_PROGRESS
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_completed_project_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.lc_project_status = LanguageCloudStatus.COMPLETED
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_archived_project_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.lc_project_status = LanguageCloudStatus.ARCHIVED
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_failed_project_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.create_attempts = 3
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_project_created_remotely_but_not_the_files_is_excluded(self):
+        project = self._add_project_from_settings()
+        project.lc_project_id = "123"
+        project.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_project_with_some_remote_files_created_is_excluded(self):
+        project = self._add_project_from_settings()
+        lc_file = project.languagecloudfile_set.first()
+        lc_file.lc_source_file_id = "123"
+        lc_file.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 0)
+
+    def test_project_and_all_remote_files_created_but_not_started_completed_or_archived_is_included(
+        self,
+    ):
+        project = self._add_project_from_settings()
+        project.lc_project_id = "123"
+        project.save()
+
+        for lc_file in project.languagecloudfile_set.all():
+            lc_file.lc_source_file_id = f"foo_{lc_file.id}"
+            lc_file.save()
+
+        self.assertEqual(sync._get_projects_to_start().count(), 1)
